about summary refs log tree commit diff
path: root/src/liballoc
diff options
context:
space:
mode:
authorSimon Sapin <simon.sapin@exyr.org>2018-04-03 14:41:15 +0200
committerSimon Sapin <simon.sapin@exyr.org>2018-04-12 22:52:47 +0200
commit09e8db1e4f33ec82316e1eeaaedad94fe6e1acb5 (patch)
tree0f69b9f8aa81b45c927d22d9db37f7ab7bc81050 /src/liballoc
parent1b895d8b88413f72230fbc0f00c67328870a2e9a (diff)
downloadrust-09e8db1e4f33ec82316e1eeaaedad94fe6e1acb5.tar.gz
rust-09e8db1e4f33ec82316e1eeaaedad94fe6e1acb5.zip
Rename `heap` modules in the core, alloc, and std crates to `alloc`
Diffstat (limited to 'src/liballoc')
-rw-r--r--src/liballoc/alloc.rs (renamed from src/liballoc/heap.rs)0
-rw-r--r--src/liballoc/lib.rs8
2 files changed, 6 insertions, 2 deletions
diff --git a/src/liballoc/heap.rs b/src/liballoc/alloc.rs
index 000c0123d9f..000c0123d9f 100644
--- a/src/liballoc/heap.rs
+++ b/src/liballoc/alloc.rs
diff --git a/src/liballoc/lib.rs b/src/liballoc/lib.rs
index 5ca39442342..617bc5c52b3 100644
--- a/src/liballoc/lib.rs
+++ b/src/liballoc/lib.rs
@@ -57,7 +57,7 @@
 //!
 //! ## Heap interfaces
 //!
 //! The [`heap`](heap/index.html) module defines the low-level interface to the
 //! default global allocator. It is not compatible with the libc allocator API.
 
 #![allow(unused_attributes)]
@@ -145,7 +145,11 @@ pub use core::heap as allocator;
 
 // Heaps provided for low-level allocation strategies
 
-pub mod heap;
+pub mod alloc;
+
+#[unstable(feature = "allocator_api", issue = "32838")]
+#[rustc_deprecated(since = "1.27.0", reason = "module renamed to `alloc`")]
+pub use alloc as heap;
 
 // Primitive types using the heaps above
@@ -57,7 +57,7 @@
 //! ## Heap interfaces
 //!
-//! The [`heap`](heap/index.html) module defines the low-level interface to the
+//! The [`alloc`](alloc/index.html) module defines the low-level interface to the
 //! default global allocator. It is not compatible with the libc allocator API.
 